---
slug: /delete-collection-of-api
---

# delete_collection - Delete a Collection

The `delete_collection()` method is used to delete a specified Collection.

:::info

This API is only available when you are connected to the database using a client. For more information about the client, see [Client](../50.client.md).

:::

## Prerequisites

* You have installed pyseekdb. For more information about how to install pyseekdb, see [Get Started](../../10.pyseekdb-sdk/10.pyseekdb-sdk-get-started.md).

* You are connected to the database. For more information about how to connect to the database, see [Client](../50.client.md).

* The Collection you want to delete exists. If the Collection does not exist, an error will be returned.

## Request parameters

```python
client.delete_collection(name)
```

|Parameter|Type|Required|Description|Example value|
|---|---|---|---|---|
|`name`|string|Yes|The name of the Collection to be deleted. |my_collection|

## Request example

```python
import pyseekdb

# Create a client
client = pyseekdb.Client()

# Delete a collection
client.delete_collection("my_collection")
```

## Response parameters

None

## References

* [Create a collection](100.create-collection-of-api.md)
* [Query a collection](200.get-collection-of-api.md)
* [Create or query a collection](250.get-or-create-collection-of-api.md)
* [Get a collection list](300.list-collection-of-api.md)
* [Count the number of collections](350.count-collection-of-api.md)
